<?php

namespace Drupal\dynamic_queues\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Dynamic Queue Config Form.
 */
class DynamicQueuesConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'dynamic_queues.settings_form',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'dynamic_queues_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('dynamic_queues.settings_form');

    $form['dynamic_queues']['max_queue_limit'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Maximum Queue limit'),
      '#description' => $this->t('Please enter the number here to hold the maximum item per queue.'),
      '#required' => FALSE,
      '#default_value' => $config->get('max_queue_limit'),
    ];

    $form['dynamic_queues']['multiple_queue_names'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Queue names'),
      '#description' => $this->t('Please use "|" sybmol for multiple queue names. ex:newsletter|announcement|notification...'),
      '#required' => FALSE,
      '#default_value' => $config->get('multiple_queue_names'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('dynamic_queues.settings_form')
      ->set('max_queue_limit', $form_state->getValue('max_queue_limit'))
      ->set('multiple_queue_names', $form_state->getValue('multiple_queue_names'))
      ->save();
  }

}
